@@ -333,9 +333,6 @@ terminal_widget_context_menu (TerminalWidget *widget,
   /* take a reference on the menu */
   g_object_ref_sink (G_OBJECT (menu));
 
-  if (event_time == 0)
-    event_time = gtk_get_current_event_time ();
-
   loop = g_main_loop_new (NULL, FALSE);
 
   /* connect the deactivate handler */
@@ -349,7 +346,8 @@ terminal_widget_context_menu (TerminalWidget *widget,
 #if GTK_CHECK_VERSION (3, 22, 0)
   gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
 #else
-  gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, button, event_time);
+  gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, button,
+                  event_time > 0 ? event_time : gtk_get_current_event_time ());
 #endif
   g_main_loop_run (loop);
   g_main_loop_unref (loop);
@@ -384,18 +382,18 @@ static gboolean
 terminal_widget_button_press_event (GtkWidget       *widget,
                                     GdkEventButton  *event)
 {
-  GdkModifierType modifiers = gtk_accelerator_get_default_mod_mask ();
-  gboolean        committed = FALSE;
-  gboolean        middle_click_opens_uri;
-  gchar          *match;
-  guint           signal_id = 0;
-  gint            tag;
+  const GdkModifierType modifiers = gtk_accelerator_get_default_mod_mask ();
+  gboolean              committed = FALSE;
+  gboolean              middle_click_opens_uri;
+  gchar                *match;
+  guint                 signal_id = 0;
+  gint                  tag;
 
   if (event->type == GDK_BUTTON_PRESS)
     {
       /* check whether to use ctrl-click or middle click to open URI */
       g_object_get (G_OBJECT (TERMINAL_WIDGET (widget)->preferences),
-          "misc-middle-click-opens-uri", &middle_click_opens_uri, NULL);
+                    "misc-middle-click-opens-uri", &middle_click_opens_uri, NULL);
 
       if (middle_click_opens_uri
             ? (event->button == 2)
@@ -648,10 +646,10 @@ terminal_widget_open_uri (TerminalWidget *widget,
                           const gchar    *wlink,
                           gint            tag)
 {
-  GError      *error = NULL;
-  gchar       *uri;
-  guint        i;
-  GdkScreen   *screen;
+  GtkWindow *window = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (widget)));
+  GError    *error = NULL;
+  gchar     *uri, *escaped;
+  guint      i;
 
   for (i = 0; i < G_N_ELEMENTS (regex_patterns); i++)
     {
@@ -671,10 +669,8 @@ terminal_widget_open_uri (TerminalWidget *widget,
             break;
 
           case PATTERN_TYPE_EMAIL:
-            if (strncmp (wlink, MAILTO, strlen (MAILTO)) == 0)
-              uri = g_strdup (wlink);
-            else
-              uri = g_strconcat (MAILTO, wlink, NULL);
+            uri = strncmp (wlink, MAILTO, strlen (MAILTO)) == 0
+                ? g_strdup (wlink) : g_strconcat (MAILTO, wlink, NULL);
             break;
 
           default:
@@ -683,14 +679,18 @@ terminal_widget_open_uri (TerminalWidget *widget,
         }
 
       /* try to open the URI with the responsible application */
-      screen = gtk_widget_get_screen (GTK_WIDGET (widget));
-      if (!gtk_show_uri (screen, uri, gtk_get_current_event_time (), &error))
+#if GTK_CHECK_VERSION (3, 22, 0)
+      if (!gtk_show_uri_on_window (window, uri, gtk_get_current_event_time (), &error))
+#else
+      if (!gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (widget)),
+                         uri, gtk_get_current_event_time (), &error))
+#endif
         {
           /* escape ampersand symbols, etc. */
-          uri = g_markup_escape_text (uri, -1);
+          escaped = g_markup_escape_text (uri, -1);
           /* tell the user that we were unable to open the responsible application */
-          xfce_dialog_show_error (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (widget))),
-                                  error, _("Failed to open the URL '%s'"), uri);
+          xfce_dialog_show_error (window, error, _("Failed to open the URL '%s'"), escaped);
+          g_free (escaped);
           g_error_free (error);
         }
 
@@ -721,8 +721,7 @@ terminal_widget_update_highlight_urls (TerminalWidget *widget)
       for (i = 0; i < G_N_ELEMENTS (regex_patterns); i++)
         if (widget->regex_tags[i] != -1)
           {
-            vte_terminal_match_remove (VTE_TERMINAL (widget),
-                                       widget->regex_tags[i]);
+            vte_terminal_match_remove (VTE_TERMINAL (widget), widget->regex_tags[i]);
             widget->regex_tags[i] = -1;
           }
     }
@@ -751,17 +750,14 @@ terminal_widget_update_highlight_urls (TerminalWidget *widget)
 #endif
           if (G_UNLIKELY (error != NULL))
             {
-              g_critical ("Failed to parse regular expression pattern %d: %s",
-                          i, error->message);
+              g_critical ("Failed to parse regular expression pattern %d: %s", i, error->message);
               g_error_free (error);
               continue;
             }
 
           /* set the new regular expression */
-          widget->regex_tags[i] = vte_terminal_match_add_gregex (VTE_TERMINAL (widget),
-                                                                 regex, 0);
-          vte_terminal_match_set_cursor_type (VTE_TERMINAL (widget),
-                                              widget->regex_tags[i], GDK_HAND2);
+          widget->regex_tags[i] = vte_terminal_match_add_gregex (VTE_TERMINAL (widget), regex, 0);
+          vte_terminal_match_set_cursor_type (VTE_TERMINAL (widget), widget->regex_tags[i], GDK_HAND2);
           /* release the regex owned by vte now */
           g_regex_unref (regex);
         }
